# Traducciones

Por convenio los textos originales en WordPress deben estar en **inglés**.

Dentro de nuestro código usa las funciones disponibles del CMS. Por ejemplo:

```php
esc_html__( 'You are not currently logged in.', 'flat101-security' ),
```

> Siempre debemos usar nuestro _text domain_: `'flat101-security'`. No usar constantes, variables,... como segundo parámetro.

## Funciones escapadas

Cuando vamos a mostrar la cadena traducida preferiremos las versiones escapadas que protegen nuestro código:

-   [esc_html\_\_()](https://developer.wordpress.org/reference/functions/esc_html__/)
-   [esc_html_e()](https://developer.wordpress.org/reference/functions/esc_html_e/)
-   [esc_html_x()](https://developer.wordpress.org/reference/functions/esc_html_x/)
-   [esc_attr\_\_()](https://developer.wordpress.org/reference/functions/esc_attr__/)
-   [esc_attr_e()](https://developer.wordpress.org/reference/functions/esc_attr_e/)
-   [esc_attr_x()](https://developer.wordpress.org/reference/functions/esc_attr_x/)

También evita incluir código HTML en la traducción:

```php
$anchor = esc_html_x( 'this link', 'link text for google.com', 'txt-domain' );
$link = sprintf( '<a href="https://goo.gl">%s</a>', $anchor );

/* translators: %s: is a link */
echo sprintf( esc_html__( 'Please read %s to check it.', 'example-domain' ), $link );
```

Si quieres permitir HTML:

-   [wp_kses_post()](https://developer.wordpress.org/reference/functions/wp_kses_post/) o [wp_kses()](https://developer.wordpress.org/reference/functions/wp_kses/)

Ejemplo:

```php
wp_kses_post(
	__( 'Please read <strong>more</strong>', 'example-domain' );
);
```

## Generar fichero POT

Crea o actualiza las traducciones del archivo de plantilla:

```shell
$ composer pot
```

## Instalar plugins de traducción

Para facilitar el proceso de traducción instalaremos 2 plugins:

-   [Loco Translate](https://es.wordpress.org/plugins/loco-translate/)
-   [Automatic Translate Addon For Loco Translate](https://wordpress.org/plugins/automatic-translator-addon-for-loco-translate/)

## Configurar Loco Translate

Abre el menú de _Loco Translate_ y selecciona nuestro plugin.

La primera vez nos mostrará las traducciones de `Carbon Fields`. Como no las queremos modificar abrimos la pestaña `Avanzada` y dentro del campo _Rutas bloqueadas_ escribe `lib` y guarda:

![Loco Translate - Configuración Avanzada](images/translations/loco-advanced-settings.png)

## Generar nuevo idioma

Abre el menú de Loco Translate y seleccion nuestro plugin.

Presiona sobre `Nuevo idioma`.

![Alt text](images/translations/loco-new-language.png)

Deja marcado `Idioma de WordPress` y elige uno que no tengamos.

Deja también marcada la localización `Autor` y presiona `Comenzar a traducir`.

> Esta acción genera `flat101-security-es_ES.po` y `flat101-security-es_ES.mo`.

## Traducción automática

Ahora podemos traducir cada entrada una a una o mejor usar el plugin _Automatic Translate Addon For Loco Translate_.

_Loco Translate_ tiene opción de auto-traducir pero al final todas las opciones son de pago.
Con este plugin podemos conseguirlo sin pagar.

Cuando entres desde Loco Translate a un `.po`, arriba a la derecha aparecerá un nuevo botón `Auto translate`:

![Auto translate icon](images/translations/loco-auto-translate-icon.png)

Elige: Yandex Translate

![Yandex Translate](images/translations/loco-yandex-translate.png)

> Por el momento Yandex no puede traducir cadenas con HTML.

Selecciona idioma y presiona sobre `Translate`.

![Seleccionar idioma](images/translations/loco-yandex-choose-lang.png)

Presiona `Merge Translation`.

Deja en blanco:

-   Sobrescribir traducciones existentes (desactivado por defecto)
-   Marcar nuevas traducciones como "imprecisas"

![Comenzar generación traducciones](images/translations/loco-yandex-start.png)

Añade las traducciones con `Start Adding Process`.

> Todas las traducciones automáticas deben ser revisadas.

En _Loco Translate_ podemos ir haciendo cambios de traducciones pero no serán visibles hasta que le demos a `Guardar`. En ese momento se guarda el PO y se genera el MO.

Al final debemos tener algo parecido a esto:

![Proceso terminado](images/translations/loco-lang-finish.png)

Si cambias de idioma dentro del dashboard comprobarás verás las traducciones que has creado.
