<?php
/**
 * Build the admin pages.
 *
 * @package Flat101\Security\Controller
 */

namespace Flat101\Security\Controller;

use Carbon_Fields\Carbon_Fields;
use Carbon_Fields\Container\Container;
use Flat101\Security\Service\PagesService;
use Flat101\Security\Util\Debug;

/**
 * Pages Builder class.
 */
class PagesBuilder {

	/**
	 * Initialize Carbon Fields and build the containers.
	 */
	public function build() {
			add_action( 'after_setup_theme', array( $this, 'carbon_fields_init' ) );
			add_action( 'carbon_fields_register_fields', array( $this, 'carbon_fields_build' ) );
	}

	/**
	 * Initialize the library: Carbon Fields.
	 */
	public function carbon_fields_init() {
		Debug::log( 'carbon_fields_init' );

		Carbon_Fields::boot();
	}

	/**
	 * Register a metabox with menu for each options page.
	 */
	public function carbon_fields_build() {
		Debug::log( 'carbon_fields_build' );

		$service   = PagesService::instance();
		$main_page = $service->get_main_page();

		foreach ( $service->get_pages() as $page ) {

			// Register options page (menu and form).
			// URL: /wp-admin/admin.php?page=<page_key>.
			$container = Container::make( 'theme_options', $page->get_page_title() )
			->set_page_menu_title( $page->get_menu_text() )
			->set_page_file( $page->get_key() );

			// Only for the main page.
			if ( $main_page === $page ) {
				$container->set_page_menu_position( 80 )
				->set_icon( 'dashicons-admin-site-alt3' );
			} else {
				// Only for child pages.
				$container->set_page_parent( $main_page->get_key() );
			}

			// Build blocks.
			foreach ( $page->get_blocks() as $block ) {
				$block->add_to_container( $container );
			}
		}
	}
}
