<?php
/**
 * FileEditBlock.
 *
 * @package Flat101\Security\Model\Block
 */

namespace Flat101\Security\Model\Block;

use Carbon_Fields\Field\Field;
use Flat101\Security\Model\Entity\Block;


/**
 * FileEditBlock class.
 */
/**
 * FileEditBlock class.
 */
class FileEditBlock extends Block {

	/**
	 * Constructor.
	 */
	public function __construct() {
		parent::__construct(
			esc_html__( 'File Edit', 'flat101-security' ),
			'file_edit',
			array(
				'file_edit_disabled' => true,
				)
		);
	}

	/**
	 * Returns the fields of the block so that the user can modify the configuration from the form.
	 *
	 * @link https://docs.carbonfields.net/learn/fields/usage.html
	 *
	 * @return Field[]
	 */
	public function get_fields() {
		return [
			Field::make('html', 'file_edit_information')
			     ->set_html(
				     '<p>' .
				     __('Disabling file editing is a security measure which prevents users from altering plugin and theme files via the WordPress admin interface. This can help mitigate the risk of unauthorized code alterations. For further details, refer to the <a href="https://developer.wordpress.org/apis/wp-config-php/#disable-the-plugin-and-theme-file-editor" target="_blank" rel="noopener noreferrer">WordPress documentation</a>.', 'flat101-security') .
				     '</p>'
			     ),
			Field::make('checkbox', $this->get_option_name('file_edit_disabled'), __('Disable File Editing', 'flat101-security'))
				->set_default_value( $this->default_settings['file_edit_disabled'] )
			     ->set_help_text(__('Enable this option to disable file editing via the WordPress admin interface.', 'flat101-security'))
		];
	}


	/**
	 * Execute the logic of this block. The settings will already have their values updated.
	 */
	public function run() {
		if (isset($this->settings['disabled']) && $this->settings['disabled']) {
			$this->disable_file_edit();
		}
	}

	/**
	 * Disable file editing
	 */
	public function disable_file_edit() {
		if ( ! defined('DISALLOW_FILE_EDIT') ) {
			define( 'DISALLOW_FILE_EDIT', true );
		}
	}

}
