<?php
/**
 * Disable RSS feeds.
 *
 * @package Flat101\Security\Model\Block
 */

namespace Flat101\Security\Model\Block;

use Carbon_Fields\Field\Field;
use Flat101\Security\Model\Entity\Block;

/**
 * RemoveFeedsBlock class.
 */
class RemoveFeedsBlock extends Block {

	/**
	 * Block constructor.
	 */
	public function __construct() {
		parent::__construct(
			esc_html__( 'Remove Feeds', 'flat101-security' ),
			'remove_feeds',
			array(
				'disable_all_feeds' => false,
				'disable_rdf' => false,
				'disable_rss' => false,
				'disable_rss2' => false,
				'disable_atom' => false,
			)
		);
	}

	public function get_fields() {
		return array(
			Field::make( 'html', 'remove_feeds_description' )
			     ->set_html(
				     '<p>Enabling these features will disable the specified RSS feeds on your WordPress site. This can help prevent content scraping and unauthorized distribution of your site\'s content.</p>'
			     ),
			Field::make( 'checkbox', $this->get_option_name( 'disable_all_feeds' ), __( 'Disable all feeds', 'flat101-security' ) )
			     ->set_default_value( $this->default_settings['disable_all_feeds'] ),
			Field::make( 'checkbox', $this->get_option_name( 'disable_rdf' ), __( 'Disable RDF feed', 'flat101-security' ) )
			     ->set_default_value( $this->default_settings['disable_rdf'] ),
			Field::make( 'checkbox', $this->get_option_name( 'disable_rss' ), __( 'Disable RSS feed', 'flat101-security' ) )
			     ->set_default_value( $this->default_settings['disable_rss'] ),
			Field::make( 'checkbox', $this->get_option_name( 'disable_rss2' ), __( 'Disable RSS2 feed', 'flat101-security' ) )
			     ->set_default_value( $this->default_settings['disable_rss2'] ),
			Field::make( 'checkbox', $this->get_option_name( 'disable_atom' ), __( 'Disable Atom feed', 'flat101-security' ) )
			     ->set_default_value( $this->default_settings['disable_atom'] ),
		);
	}

	/**
	 * Run block options
	 */
	public function run() {
		// If "disable all feeds" is selected, add actions for all feed types
		if ( $this->settings['disable_all_feeds'] ) {
			$this->disable_all_feeds();
		} else {
			// Otherwise, check each feed type individually
			if ( $this->settings['disable_rdf'] ) {
				add_action('do_feed_rdf', [$this, 'disable_feed'], 1);
			}
			if ( $this->settings['disable_rss'] ) {
				add_action('do_feed_rss', [$this, 'disable_feed'], 1);
			}
			if ( $this->settings['disable_rss2'] ) {
				add_action('do_feed_rss2', [$this, 'disable_feed'], 1);
			}
			if ( $this->settings['disable_atom'] ) {
				add_action('do_feed_atom', [$this, 'disable_feed'], 1);
			}
		}
	}

	/**
	 * Disable all RSS feed functionalities.
	 */
	private function disable_all_feeds() {
		// Add the action for all feed types
		add_action('do_feed', [$this, 'disable_feed'], 1);
		add_action('do_feed_rdf', [$this, 'disable_feed'], 1);
		add_action('do_feed_rss', [$this, 'disable_feed'], 1);
		add_action('do_feed_rss2', [$this, 'disable_feed'], 1);
		add_action('do_feed_atom', [$this, 'disable_feed'], 1);
	}

	/**
	 * The method that's hooked into the feed actions.
	 */
	public function disable_feed() {
		wp_die( __('Sorry, our content is not available through RSS. Please visit our <a href="'. get_bloginfo('url') .'">website</a> to read it.') );
	}
}
