<?php
/**
 * Initialize and review the pages of this plugin.
 *
 * @package Flat101\Security\Service
 */

namespace Flat101\Security\Service;

use Flat101\Security\Model\Entity\Page;

/**
 * Pages Service class.
 */
class PagesService {

	/**
	 * List of pages. The first will be the main one and the others will be its children.
	 *
	 * @var Page[];
	 */
	protected $pages = array();


	/**
	 * Singleton pattern. Use 'instance()' static method.
	 */
	private function __construct() {}


	/**
	 * List of pages. The first will be the main one and the others will be its children.
	 *
	 * @return Page[]
	 */
	public function get_pages() {
		return $this->pages;
	}

	/**
	 * Returns the main page.
	 *
	 * @return Page|null
	 */
	public function get_main_page() {
		return empty( $this->pages ) ? null : $this->pages[0];
	}

	/**
	 * Update the array of pages.
	 *
	 * @param Page[] $pages Array of pages.
	 */
	public function set_pages( $pages ) {
		$this->pages = $pages;
	}


	/**
	 * Load the pages.
	 */
	public function load() {

		// Load from config file.
		$this->pages = include FLAT101_SECURITY_PAGES_CONFIG_FILE;
	}


	/**
	 * Gets the instance of this service.
	 *
	 * @return self
	 */
	public static function instance() {
		static $self = null;

		if ( null === $self ) {
			$self = new self();
			$self->load();
		}

		return $self;
	}
}
